[ONOS-5539] Process sub tree defect fix

Change-Id: I6e06a8ca430a86cc538543b161bbbc56dc9cade6
diff --git a/generator/src/main/java/org/onosproject/yangutils/utils/UtilConstants.java b/generator/src/main/java/org/onosproject/yangutils/utils/UtilConstants.java
index 8266eca..3a1a1f5 100644
--- a/generator/src/main/java/org/onosproject/yangutils/utils/UtilConstants.java
+++ b/generator/src/main/java/org/onosproject/yangutils/utils/UtilConstants.java
@@ -167,11 +167,6 @@
     public static final String JAVA_DOC_BUILD = " * Builds object of ";
 
     /**
-     * JavaDocs's return statement for build method.
-     */
-    public static final String JAVA_DOC_BUILD_RETURN = "object of ";
-
-    /**
      * JavaDocs's statement for builder object.
      */
     public static final String BUILDER_OBJECT = "builder object of ";
@@ -238,11 +233,6 @@
     public static final String COMPARE_TO = "compareTo";
 
     /**
-     * Static attribute for period.
-     */
-    public static final String INVOKE = "invoke";
-
-    /**
      * Static attribute for parse byte.
      */
     public static final String PARSE_BYTE = "parseByte";
@@ -340,11 +330,6 @@
     public static final String SCHEMA_NAME = "schemaName";
 
     /**
-     * Static attribute for schema name value.
-     */
-    public static final String STR_VAL = "stringValue";
-
-    /**
      * Static attribute for validateRange.
      */
     public static final String VALIDATE_RANGE = "validateRange";
@@ -506,11 +491,6 @@
     public static final String SUBJECT = "Subject";
 
     /**
-     * Static attribute for ListenerRegistry.
-     */
-    public static final String LISTENER_REG = "ListenerRegistry";
-
-    /**
      * Static attribute for ListenerService.
      */
     public static final String LISTENER_SERVICE = "ListenerService";
@@ -551,11 +531,6 @@
     public static final String LEAFREF = "leafref";
 
     /**
-     * Static attribute for identityref string.
-     */
-    public static final String IDENTITYREF = "identityref";
-
-    /**
      * Static attribute for output variable of rpc.
      */
     public static final String RPC_INPUT_VAR_NAME = "inputVar";
@@ -576,11 +551,6 @@
     public static final String ADD = "+";
 
     /**
-     * Static attribute for single quote.
-     */
-    public static final String SINGLE_QUOTE = "\'";
-
-    /**
      * Static attribute for quotes.
      */
     public static final String QUOTES = "\"";
@@ -626,11 +596,6 @@
     public static final char CHAR_OF_OPEN_SQUARE_BRACKET = '[';
 
     /**
-     * Static attribute for close square bracket character.
-     */
-    public static final char CHAR_OF_CLOSE_SQUARE_BRACKET = ']';
-
-    /**
      * Static attribute for slash string.
      */
     public static final String SLASH_FOR_STRING = "/";
@@ -656,11 +621,6 @@
     public static final String ADD_STRING = "add";
 
     /**
-     * Static attribute for string replace syntax.
-     */
-    public static final String REPLACE_STRING = "replace";
-
-    /**
      * Static attribute for string trim syntax.
      */
     public static final String TRIM_STRING = "trim";
@@ -735,11 +695,6 @@
     public static final String IF = "if";
 
     /**
-     * Static attribute for else-if.
-     */
-    public static final String ELSE_IF = "else if";
-
-    /**
      * Static attribute for of.
      */
     public static final String OF = "of";
@@ -889,37 +844,11 @@
     public static final String GET_METHOD_PREFIX = "get";
 
     /**
-     * Static attribute for getter method prefix.
-     */
-    public static final String GET_METHOD = "getMethod";
-
-    /**
-     * Static attribute for getter method prefix.
-     */
-    public static final String GET_CLASS = "getClass()";
-
-    /**
      * Static attribute for setter method prefix.
      */
     public static final String SET_METHOD_PREFIX = "set";
 
     /**
-     * Static attribute for get filter leaf flags.
-     */
-    public static final String GET_VALUE_LEAF_FLAGS = "getValueLeafFlags";
-
-    /**
-     * Static attribute for get select filter leaf flags.
-     */
-    public static final String GET_SELECT_LEAF_FLAGS = "getSelectLeafFlags";
-
-
-    /**
-     * Static attribute for getLeafIndex.
-     */
-    public static final String GET_LEAF_INDEX = "getLeafIndex()";
-
-    /**
      * Static attribute for op param.
      */
     public static final String OP_PARAM = "OpParam";
@@ -1066,11 +995,6 @@
             TWENTY_EIGHT_SPACE_INDENTATION + FOUR_SPACE_INDENTATION;
 
     /**
-     * continue.
-     */
-    public static final String CONTINUE = "continue";
-
-    /**
      * Static attribute for generated code path.
      */
     public static final String YANG_GEN_DIR = "src/main/java/";
@@ -1335,11 +1259,6 @@
     public static final String BUILDER_LOWER_CASE = "builder";
 
     /**
-     * Static attribute for manager syntax.
-     */
-    public static final String MANAGER = "Manager";
-
-    /**
      * Static attribute for service syntax.
      */
     public static final String SERVICE = "Service";
@@ -1470,9 +1389,9 @@
     public static final String COLLECTION_IMPORTS = "java.util";
 
     /**
      * Static attribute for regex.
      */
-    public static final String REGEX_IMPORTS = "java.util.regex";
+    public static final String REFLECT_IMPORTS = "java.lang.reflect";
 
     /**
      * Static attribute for map.
@@ -1531,9 +1450,9 @@
     public static final String SET_VALUE_PARA = "setValue";
 
     /**
-     * Static attribute for java utilities import package.
+     * Static attribute for Method.
      */
-    public static final String HELPER = "helper";
+    public static final String METHOD = "Method";
 
     /**
      * Static attribute for bitset.
@@ -1583,7 +1502,7 @@
     public static final String SET = "Set";
 
     /**
-     * Comment to be added for autogenerated impl methods.
+     * Comment to be added for auto generated impl methods.
      */
     public static final String YANG_UTILS_TODO =
             "//TODO: YANG utils generated code";
@@ -1749,18 +1668,6 @@
     public static final String FOR = "for";
 
     /**
-     * Static attribute for YangAugmentedOpParamInfo.
-     */
-    public static final String YANG_AUGMENTED_OP_PARAM_INFO =
-            "YangAugmentedOpParamInfo";
-
-    /**
-     * Static attribute for NoSuchMethodException.
-     */
-    public static final String NO_SUCH_METHOD_EXCEPTION =
-            "NoSuchMethodException";
-
-    /**
      * Static attribute for InvocationTargetException.
      */
     public static final String INVOCATION_TARGET_EXCEPTION =
@@ -1771,11 +1678,6 @@
      */
     public static final String INVOCATION_TARGET_EXCEPTION_IMPORT = "import" +
             " java.lang.reflect.InvocationTargetException;\n";
-    /**
-     * Static attribute for IllegalAccessException.
-     */
-    public static final String ILLEGAL_ACCESS_EXCEPTION =
-            "IllegalAccessException";
 
     /**
      * Static attribute for arrayList.
@@ -1861,21 +1763,11 @@
     public static final String BUILDER_INTERFACE = "builder interface";
 
     /**
-     * Static attribute for binary.
-     */
-    public static final String BINARY = "binary";
-
-    /**
      * Static attribute for bits.
      */
     public static final String BITS = "bits";
 
     /**
-     * Static attribute for bits.
-     */
-    public static final String BITS_CAPS = "Bits";
-
-    /**
      * Static attribute for YANG.
      */
     public static final String YANG = "yang";
@@ -1951,11 +1843,6 @@
     public static final String SELECT_ALL_CHILD_SCHEMA_PARAM =
             "isSelectAllSchemaChild";
 
-    /**
-     * Static param for ResultOfProcessSubTree.
-     */
-    public static final String CHOICE_STF_METHOD_NAME =
-            "ResultOfProcessSubTree";
     //File type extension for java classes.
     public static final String JAVA_FILE_EXTENSION = ".java";
@@ -1470,9 +1389,9 @@
 
     /**
-     * Static attribute for regex.
+     * Static attribute for reflect.
      */